@@ -296,7 +296,7 @@ def analyze_video(path: Path, thumbnail: Path = None) -> tuple:
     except ImportError:
         raise Exception("Please install moviepy>=1.0.3 and retry")
 
-    print(f'Analizing IGTV file "{path}"')
+    print(f'Analyzing IGTV file "{path}"')
     video = mp.VideoFileClip(str(path))
     width, height = video.size
     if not thumbnail:
